# Changelog

All notable changes to this project will be documented in this file.

## [0.0.2] - 2026-03-17

- chore: Stricter control on power levels during room creation and after, and more! [#30](https://github.com/famedly/famedly-control-synapse/pull/30)
- docs: document the module [#28](https://github.com/famedly/famedly-control-synapse/pull/28)
- fix: prohibit overriding specific power levels during room creation [#29](https://github.com/famedly/famedly-control-synapse/pull/29)
- tests: Remove patching for batched external user id calls [#24](https://github.com/famedly/famedly-control-synapse/pull/24)
- Add some niche power level tests and simplify defaults logic a tiny bit [#15](https://github.com/famedly/famedly-control-synapse/pull/15)
- chore: return proper error code for client response [#27](https://github.com/famedly/famedly-control-synapse/pull/27)
- fix: extra slash in constructed client urls [#25](https://github.com/famedly/famedly-control-synapse/pull/25)
- fix: Don't clobber other users in `power_level_content_override` [#26](https://github.com/famedly/famedly-control-synapse/pull/26)

## [0.0.1] - 2026-03-10

- Initial release
